@@ -5,6 +5,7 @@
 """
 
 from os import linesep
+from sys import getsizeof
 from ._check import set_array, check_var, raise_
 from ..Functions.save import save
 from ..Functions.copy import copy
@@ -49,6 +50,7 @@ class DataTime(DataND):
         axes=None,
         FTparameters=-1,
         values=None,
+        is_real=True,
         symbol="",
         name="",
         unit="",
@@ -77,6 +79,8 @@ class DataTime(DataND):
                 FTparameters = init_dict["FTparameters"]
             if "values" in list(init_dict.keys()):
                 values = init_dict["values"]
+            if "is_real" in list(init_dict.keys()):
+                is_real = init_dict["is_real"]
             if "symbol" in list(init_dict.keys()):
                 symbol = init_dict["symbol"]
             if "name" in list(init_dict.keys()):
@@ -91,6 +95,7 @@ class DataTime(DataND):
             axes=axes,
             FTparameters=FTparameters,
             values=values,
+            is_real=is_real,
             symbol=symbol,
             name=name,
             unit=unit,
@@ -118,6 +123,15 @@ class DataTime(DataND):
             return False
         return True
 
+    def __sizeof__(self):
+        """Return the size in memory of the object (including all subobject)"""
+
+        S = 0  # Full size of the object
+
+        # Get size of the properties inherited from DataND
+        S += super(DataTime, self).__sizeof__()
+        return S
+
     def as_dict(self):
         """Convert this object in a json seriable dict (can be use in __init__)"""
 
