@@ -16,6 +16,7 @@ from numpy import (
     pi,
     zeros,
     exp,
+    ceil,
     iscomplex,
     concatenate,
     conjugate,
@@ -92,72 +93,88 @@ def comp_fft_time(freqs, is_angle, is_real):
     return time.tolist()
 
 
-# def comp_nthoctave_axis(noct, freqmin, freqmax):
-#     """Computes the frequency vector between freqmin and freqmax for the 1/n octave
-#     Parameters
-#     ----------
-#     noct: int
-#         kind of octave band (1/3, etc)
-#     freqmin: float
-#         minimum frequency
-#     freqmax: float
-#         maximum frequency
-#     Returns
-#     -------
-#     Frequency vector
-#     """
-#     if noct == 3:
-#         table = [
-#             10,
-#             12.5,
-#             16,
-#             20,
-#             25,
-#             31.5,
-#             40,
-#             50,
-#             63,
-#             80,
-#             100,
-#             125,
-#             160,
-#             200,
-#             250,
-#             315,
-#             400,
-#             500,
-#             630,
-#             800,
-#             1000,
-#             1250,
-#             1600,
-#             2000,
-#             2500,
-#             3150,
-#             4000,
-#             5000,
-#             6300,
-#             8000,
-#             10000,
-#             12500,
-#             16000,
-#             20000,
-#         ]
-#         f_oct = [f for f in table if (f >= freqmin and f <= freqmax)]
-#     else:
-#         f0 = 1000
-#         f_oct = [f0]
-#         i = 1
-#         while f_oct[-1] <= freqmax:
-#             f_oct.append(f0 * 2.0 ** (i / noct))
-#             i = i + 1
-#         f_oct = f_oct[:-2]
-#         i = -1
-#         while f_oct[0] > freqmin:
-#             f_oct.insert(0, f0 * 2.0 ** (i / noct))
-#             i = i - 1
-#         f_oct = f_oct[1:]
-#     return f_oct
+def comp_nthoctave_axis(noct, freqmin, freqmax):
+    """Computes the frequency vector between freqmin and freqmax for the 1/n octave
+    Parameters
+    ----------
+    noct: int
+        kind of octave band (1/3, etc)
+    freqmin: float
+        minimum frequency
+    freqmax: float
+        maximum frequency
+    Returns
+    -------
+    Frequency vector
+    """
+    if noct == 3:
+        table = [
+            12.5,
+            16,
+            20,
+            25,
+            31.5,
+            40,
+            50,
+            63,
+            80,
+            100,
+            125,
+            160,
+            200,
+            250,
+            315,
+            400,
+            500,
+            630,
+            800,
+            1000,
+            1250,
+            1600,
+            2000,
+            2500,
+            3150,
+            4000,
+            5000,
+            6300,
+            8000,
+            10000,
+            12500,
+            16000,
+            20000,
+        ]
+        f_oct = [f for f in table if (f >= freqmin and f <= freqmax)]
+    elif noct == 1:
+        table = [
+            16,
+            31.5,
+            63,
+            125,
+            250,
+            500,
+            1000,
+            2000,
+            4000,
+            8000,
+            16000,
+        ]
+        f_oct = [f for f in table if (f >= freqmin and f <= freqmax)]
+    else:
+        f0 = 1000
+        f_oct = [f0]
+        i = 1
+        while f_oct[-1] <= freqmax:
+            f = f0 * 2.0 ** (i / noct)
+            f_oct.append(0.5 * ceil(2.0 * f))
+            i = i + 1
+        f_oct = f_oct[:-1]
+        i = -1
+        while f_oct[0] > freqmin:
+            f = f0 * 2.0 ** (i / noct)
+            f_oct = [0.5 * ceil(2.0 * f)] + f_oct
+            i = i - 1
+        f_oct = f_oct[1:]
+    return f_oct
 
 
 # def _comp_fft(values, is_positive=False):
