@@ -62,6 +62,11 @@ def read_input_strings(args, axis_data):
             elems = axis_str.split("=mean")
             name = elems[0]
             extension = "mean"
+        # Detect integrate
+        elif "integrate" in axis_str:
+            elems = axis_str.split("=integrate")
+            name = elems[0]
+            extension = "integrate"
         # Detect periods
         elif "oneperiod" in axis_str:
             elems = axis_str.split("[")
@@ -111,13 +116,18 @@ def read_input_strings(args, axis_data):
         elif "=[" in axis_str:
             elems = axis_str.split("=[")
             elems2 = elems[1].split(",")
-            init_str = elems2[0]
-            interval_init = eval(init_str)
-            final_str = elems2[1].strip("]")
-            interval_final = eval(final_str)
-            name = elems[0]
-            extension = "interval"
-            input_data = [interval_init, interval_final]
+            if len(elems2) > 2:
+                extension = "list"
+                name = elems[0]
+                input_data = [eval(elem.strip("]")) for elem in elems2]
+            else:
+                init_str = elems2[0]
+                interval_init = eval(init_str)
+                final_str = elems2[1].strip("]")
+                interval_final = eval(final_str)
+                name = elems[0]
+                extension = "interval"
+                input_data = [interval_init, interval_final]
         # Detect single value
         elif "=" in axis_str:
             elems = axis_str.split("=")
@@ -146,6 +156,12 @@ def read_input_strings(args, axis_data):
         else:
             name = axis_str
             extension = "whole"
+        # Detect 1/nth octave band
+        if "oct" in unit:
+            noct = int(unit.split("oct")[0].split("/")[1])
+            unit = "SI"
+        else:
+            noct = None
         # RequestedAxis object creation
         axis = RequestedAxis(
             name=name,
@@ -154,6 +170,7 @@ def read_input_strings(args, axis_data):
             values=values,
             indices=indices,
             input_data=input_data,
+            noct=noct,
         )
         axes_list.append(axis)
     return axes_list
