@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
-from numpy import tile, concatenate, negative, ones
+from SciDataTool.Functions import AxisError
+from numpy import tile, concatenate, negative, ones, append
 
 
 def rebuild_symmetries(values, axis_index, symmetries):
@@ -43,20 +44,40 @@ def rebuild_symmetries_axis(values, symmetries):
     values_new = values
     if "period" in symmetries.keys():
         for i in range(symmetries.get("period") - 1):
-            values_new = concatenate(
-                (
-                    values_new,
-                    values + (values_new[-1] - values_new[-2]) + values_new[-1],
+            if len(values) == 1:
+                if "delta" in symmetries.keys():
+                    values_new = append(
+                        values_new, values_new[-1] + symmetries["delta"]
+                    )
+                else:
+                    raise AxisError(
+                        "ERROR: must provide delta for symmetries with one sample"
+                    )
+            else:
+                values_new = concatenate(
+                    (
+                        values_new,
+                        values + (values_new[-1] - values_new[-2]) + values_new[-1],
+                    )
                 )
-            )
     elif "antiperiod" in symmetries.keys():
         for i in range(symmetries.get("antiperiod") - 1):
-            values_new = concatenate(
-                (
-                    values_new,
-                    values + (values_new[-1] - values_new[-2]) + values_new[-1],
+            if len(values) == 1:
+                if "delta" in symmetries.keys():
+                    values_new = append(
+                        values_new, values_new[-1] + symmetries["delta"]
+                    )
+                else:
+                    raise AxisError(
+                        "ERROR: must provide delta for symmetries with one sample"
+                    )
+            else:
+                values_new = concatenate(
+                    (
+                        values_new,
+                        values + (values_new[-1] - values_new[-2]) + values_new[-1],
+                    )
                 )
-            )
     return values_new
 
 
