@@ -1,6 +1,8 @@
 # -*- coding: utf-8 -*-
 from SciDataTool.Functions import AxisError, axes_dict, rev_axes_dict
 
+from numpy import inf
+
 
 def comp_axes(self, axes_list):
     """Completes the RequestedAxis objects in axes_list.
@@ -24,8 +26,8 @@ def comp_axes(self, axes_list):
                 axis_requested.index = index
                 axis_requested.corr_name = axis_name
                 axis_requested.corr_unit = axis.unit
-                if axis_name in axes_dict.keys():
-                    axis_requested.transform = axes_dict[axis_name][1]
+                # if axis_name in axes_dict.keys():
+                #     axis_requested.transform = axes_dict[axis_name][1]
         if axis_requested.index is None:
             # Check if requested axis is in correspondance dicts
             if axis_name in axes_dict.keys():
@@ -61,5 +63,5 @@ def comp_axes(self, axes_list):
                 axes_list.remove(axis_requested)
     # Extract the requested axes (symmetries + unit)
     for axis_requested in axes_list:
-        axis_requested.get_axis(self.axes[axis_requested.index])
+        axis_requested.get_axis(self.axes[axis_requested.index], is_real=self.is_real)
     return axes_list, transforms
