@@ -13,7 +13,9 @@ def has_period(self):
     """
     answer = False
 
-    if self.symmetries != {}:
-        answer = True
+    for axis in self.axes:
+
+        if axis.symmetries != {}:
+            answer = True
 
     return answer
